function _classPrivateFieldGet(receiver, privateMap) { var descriptor = _classExtractFieldDescriptor(receiver, privateMap, "get"); return _classApplyDescriptorGet(receiver, descriptor); }

function _classApplyDescriptorGet(receiver, descriptor) { if (descriptor.get) { return descriptor.get.call(receiver); } return descriptor.value; }

function _classPrivateMethodGet(receiver, privateSet, fn) { if (!privateSet.has(receiver)) { throw new TypeError("attempted to get private field on non-instance"); } return fn; }

function _classPrivateFieldSet(receiver, privateMap, value) { var descriptor = _classExtractFieldDescriptor(receiver, privateMap, "set"); _classApplyDescriptorSet(receiver, descriptor, value); return value; }

function _classExtractFieldDescriptor(receiver, privateMap, action) { if (!privateMap.has(receiver)) { throw new TypeError("attempted to " + action + " private field on non-instance"); } return privateMap.get(receiver); }

function _classApplyDescriptorSet(receiver, descriptor, value) { if (descriptor.set) { descriptor.set.call(receiver, value); } else { if (!descriptor.writable) { throw new TypeError("attempted to set read only private field"); } descriptor.value = value; } }

var _onlyForCallback = /*#__PURE__*/new WeakMap();

var _lastScrollTop = /*#__PURE__*/new WeakMap();

var _threshold = /*#__PURE__*/new WeakMap();

var _setupListeners = /*#__PURE__*/new WeakSet();

var _dispatchEvent = /*#__PURE__*/new WeakSet();

var _determineDirection = /*#__PURE__*/new WeakSet();

/**
 * ScrollDirection - a class to handle scroll direction classes on body
 *
 * Author: Bogdan Barbu
 * Team: Codingheads (codingheads.com)
 */
export class ScrollDirection {
  /**
   * start an instance
   * @param {{onlyFor: a callback to determine where to modify classes; threshold: amount in px to take into account }} param0
   */
  constructor({
    onlyFor = null,
    threshold = 0
  } = {}) {
    _determineDirection.add(this);

    _dispatchEvent.add(this);

    _setupListeners.add(this);

    _onlyForCallback.set(this, {
      writable: true,
      value: null
    });

    _lastScrollTop.set(this, {
      writable: true,
      value: 0
    });

    _threshold.set(this, {
      writable: true,
      value: 0
    });

    _classPrivateFieldSet(this, _onlyForCallback, onlyFor);

    _classPrivateFieldSet(this, _threshold, threshold);

    _classPrivateFieldSet(this, _lastScrollTop, window.pageYOffset || document.documentElement.scrollTop);

    _classPrivateMethodGet(this, _setupListeners, _setupListeners2).call(this);
  }
  /**
   * setup the scroll event listener
   */


}

function _setupListeners2() {
  window.addEventListener('scroll', () => {
    const isValid = !_classPrivateFieldGet(this, _onlyForCallback) || _classPrivateFieldGet(this, _onlyForCallback).call(this);

    if (isValid) {
      _classPrivateMethodGet(this, _determineDirection, _determineDirection2).call(this);
    }
  });
}

function _dispatchEvent2(name) {
  requestAnimationFrame(() => {
    window.dispatchEvent(new CustomEvent(name));
  });
}

function _determineDirection2() {
  const body = document.body,
        classList = body.classList;
  const scrollTop = window.pageYOffset || document.documentElement.scrollTop;
  const localThreshold = scrollTop > _classPrivateFieldGet(this, _threshold) * 2 ? _classPrivateFieldGet(this, _threshold) : 10;
  if (Math.abs(scrollTop - _classPrivateFieldGet(this, _lastScrollTop)) < localThreshold) return;

  if (scrollTop > _classPrivateFieldGet(this, _lastScrollTop) + localThreshold && !classList.contains('scrolling-down')) {
    classList.add('scrolling-down');
    classList.remove('scrolling-up');

    _classPrivateMethodGet(this, _dispatchEvent, _dispatchEvent2).call(this, 'scrollDirectionChange');
  } else if (scrollTop < _classPrivateFieldGet(this, _lastScrollTop) - localThreshold && !classList.contains('scrolling-up')) {
    classList.add('scrolling-up');
    classList.remove('scrolling-down');

    _classPrivateMethodGet(this, _dispatchEvent, _dispatchEvent2).call(this, 'scrollDirectionChange');
  }

  _classPrivateFieldSet(this, _lastScrollTop, Math.max(scrollTop, 0));
}

export default ScrollDirection;